@@ -1,23 +1,27 @@
 import shutil
 import os
-from pathlib import Path as Pa
 
 from chromie.utils import ChromiePathFinder, ManifestFile
 from chromie.enum import Initialize, Path
 
 
-def make_extension_dir(finder):
-    for d in [Path.DIST_DIR, Path.SRC_DIR, Path.STORE_DIR, Path.IMAGES_DIR]:
-        p = Pa(os.path.join(finder.root, d))
-        p.mkdir(parents=True)
-
-    with open(finder(Path.IGNORE_FILE), "w") as f:
+def make_ignore_file(root):
+    with open(os.path.join(root, Path.IGNORE_FILE), "w") as f:
         f.write("")
 
-    ManifestFile(
-        finder(Path.MANIFEST_FILE),
-        {"name": finder.name, "manifest_version": 2, "version": "0.0.0"},
-    ).write()
+
+def make_extension_dir(root, name):
+    absroot = os.path.abspath(root)
+    os.makedirs(os.path.join(absroot, Path.STORE_DIR))
+    os.makedirs(os.path.join(absroot, Path.IMAGES_DIR))
+
+    make_ignore_file(absroot)
+
+    manifest = ManifestFile(
+        os.path.join(absroot, Path.MANIFEST_FILE),
+        {"name": name, "manifest_version": 2, "version": "0.0.0"},
+    )
+    manifest.write()
 
 
 def init(args):
@@ -47,4 +51,4 @@ def init(args):
         shutil.rmtree(finder.root, ignore_errors=True)
 
     if not finder.exists(finder.root):
-        make_extension_dir(finder)
+        make_extension_dir(finder.root, finder.name)
